# Welcome to Paleos

Paleos is a lightweight python package for helping with lab based paleoclimate
data wrangling. Currently, the package implements methods to help with age
models and has examples of how existing python tools can be used to quickly 
manipulate paleoclimate related data.

Additional features may be added in the future. However, those looking for more
advanced capabilities are pointed to [pyleoclim](https://pypi.org/project/pyleoclim/).

